
djqgrid - a Django wrapper for jqGrid
=====================================
*djqgrid* is a Django wrapper for jqGrid.

*djqgrid* lets you define grids in a Django-familiar way, while taking care of most of the mundane Python-JavaScript bridge for you.

.. toctree::
   :maxdepth: 1

   installation
   example
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

